@@ -9,7 +9,7 @@ import stepwise
 from stepwise import Quantity, Q
 from voluptuous import Schema, Invalid, Coerce, And, Or, Optional
 from unittest.mock import MagicMock
-from mock_model import MockReagent, MockMolecule
+from mock_model import *
 from contextlib import nullcontext
 from pathlib import Path
 
@@ -82,7 +82,7 @@ def eval_db(reagents):
 def empty_ok(x):
     return Or(x, And('', lambda y: type(x)()))
 
-def error_or(**expected):
+def error_or(expected):
     schema = {}
 
     # Either specify an error or an expected value, not both.
@@ -173,9 +173,11 @@ eval_freezerbox = eval_with(
         approx_Q=approx_Q,
         MockReagent=MockReagent,
         MockMolecule=MockMolecule,
+        MockNucleicAcid=MockNucleicAcid,
         TEST_DIR=TEST_DIR,
 ).all(freezerbox)
 eval_pytest = eval_with().all(pytest)
+eval_python = eval_with()
 
 
 class Params:
